# NAME:
#	funcs.pl - common routines used by utils
#
# SYNOPSIS:
#	&err($ests, @args);
#	&warn(@args);
#	&show($flag,@args);
#	&dbg($flag,$level,@args);
#
# DESCRIPTION:
#	The functions err and warn print consitently formatted messages.
#	show prints its args only if $flag is non-empty and dbg if $flag
#	is greater than $level.
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: funcs.pl,v 1.8 2001/08/30 07:48:36 sjg Exp $
#
#	@(#)Copyright (c) 1997-2001 Simon J. Gerraty.
#	All rights reserved.
#	
#	This software is the property of Simon J. Gerraty.
#	It may be used only in accordance with the conditions outlined
#	in the accompanying LICENSE file. If your distribution does
#	not contain a LICENSE file, then you have no rights to use
#	this software and should contact sales@crufty.net to obtain a
#	licensed distribution.
#	
#	This software is provided "AS IS" in the hope that it will be
#	of use.  Since it is not possible to anticipate all possible
#	use of this software, there is absolutely NO WARRANTY.
#
#	Please forward bug reports and fixes to help@crufty.net
#

sub show {
  local($flag,@args) = @_;
  if ($flag ne '') {
    printf @args;
  }
}

sub dbg {
  local($flag,$level,@args) = @_;
  if ($flag > $level) {
    printf @args;
  }
}

sub dbgErr {
  local($flag,$level,@args) = @_;
  if ($flag > $level) {
    printf STDERR @args;
  }
}

sub err {
  local($e,@args) = @_;
  
  printf STDERR "$Myname: ";
  printf STDERR @args;
  printf STDERR "\n" if ($args[0] !~ m/\n$/);
  exit($e);
}

sub warn {
  printf STDERR "$Myname: ";
  printf STDERR @_;
  printf STDERR "\n" if ($_[0] !~ m/\n$/);
}

sub source {
  local($all,$file,@dirs) = @_;
  local($d);

  if ($all !~ m/^\d+/o) {
    ($file,@dirs) = @_;
    $all = 0;
  }
  @dirs = ('.', $Mydir, '/etc') if (scalar(@dirs) == 0);

  foreach $d (@dirs) {
    if (-s "$d/$file") {
      do "$d/$file";
      last unless ($all > 0);
    }
  }
}

if ($Myname ne '' && $SkipRC eq '') {
  $rc = ".${Myname}rc.pl";
  $rc =~ s/\.plrc\.pl/rc.pl/;

  &source($rc);
}

1;
